glue\_genes.glue\_single\_cell.qt.diff\_gene\_exp.DifferentialGeneExpressionListener
====================================================================================

.. currentmodule:: glue_genes.glue_single_cell.qt.diff_gene_exp

.. autoclass:: DifferentialGeneExpressionListener

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DifferentialGeneExpressionListener.__init__
      ~DifferentialGeneExpressionListener.delete_subset
      ~DifferentialGeneExpressionListener.notify
      ~DifferentialGeneExpressionListener.receive_message
      ~DifferentialGeneExpressionListener.register_to_hub
      ~DifferentialGeneExpressionListener.set_circular_refs
      ~DifferentialGeneExpressionListener.unregister
      ~DifferentialGeneExpressionListener.update_subset
   
   

   
   
   